<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/classes.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('Tarvitsen wp-config-sample.php -tiedoston lähtökohdaksi. Siirrä tämä tiedosto uudelleen WordPressin asennuskansioosi.');

$configFile = file(ABSPATH . 'wp-config-sample.php');

if ( !is_writable(ABSPATH))
	wp_die("En pysty kirjoittamaan hakemistoon. Voit muuttaa WordPressin hakemiston kirjoitusoikeuksia tai luoda wp-config.php -tiedosto käsin. ");

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>Asetustiedosto 'wp-config.php' on jo olemassa. Jos haluat nollata tiedoston sisältämät asetukset, poista se ensin. Voit sitten yrittää <a href='install.php'>asennusta uudelleen</a>.</p>");

// Check if wp-config.php exists above the root directory but is not part of another install
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>Tiedosto 'wp-config.php' on jo olemassa ylemmällä hakemistotasolla. Jos haluat nollata tiedoston sisältämät asetukset, poista se ensin. Voit sitten yrittää <a href='install.php'>asennusta uudelleen</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; Asennusasetukset</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>
<p>Tervetuloa käyttämään WordPressiä. Tarvitset seuraavat tietokantaan liittyvät tiedot ennen
jatkamista. </p>

<ol>
	<li>Tietokannan nimi</li>
	<li>Tietokannan käyttäjänimi</li>
	<li>Tietokannan salasana</li>
	<li>Tietokantapalvelin</li>
	<li>Tietokantataulujen etuliite (jos haluat tehdä useamman WordPress-asennuksen samaan tietokantaan) </li>
</ol>
<p><strong>Jos tämä automaattinen asetustyökalu ei jostain syystä toimi, ei hätää. Voit myös avata tiedoston <code>wp-config-sample.php</code> tekstieditoriin, täyttää tarvittavat tiedot ja tallentaa sen nimellä <code>wp-config.php</code>. </strong></p>
<p>Olet saanut todennäköisesti nämä tiedot palveluntarjoajaltasi. Muussa tapauksessa sinun pitää olla ensin palveluntarjoajaasi yhteydessä tietojen saamiseksi. Jos olet valmis,</p>

<p class="step"><a href="setup-config.php?step=1" class="button">Jatketaan!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>Kirjoita alle tietokannan tiedot. Jos et ole varma yksityiskohdista, ota yhteys palveluntarjoajaasi. </p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">Tietokannan nimi</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>Sen tietokannan nimi, jota haluat käyttää WordPressin kanssa. </td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">Tunnus</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>MySQL-käyttäjänimesi</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">Salasana</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>...ja MySQL-salasanasi.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">Tietokantapalvelin</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>99% todennäköisyydellä tätä arvoa ei tarvitse muuttaa.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">Tietokantataulujen etuliite</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>Jos haluat tehdä useamman WordPress-asennuksen samaan tietokantaan, muuta tämä.</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="Submit" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	$handle = fopen(ABSPATH . 'wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod(ABSPATH . 'wp-config.php', 0666);

	display_header();
?>
<p>Mainiota! Selvisit tähän asti, WordPress voi nyt ottaa yhteyttä tietokantaasi. Jos olet valmis&hellip;</p>

<p class="step"><a href="install.php" class="button">Asenna WordPress</a></p>
<?php
	break;
}
?>
</body>
</html>
